@@ -42,7 +42,7 @@ sub _prepareSObjects {
           (blessed ($obj->{$_}) and blessed ($obj->{$_}) eq 'SOAP::Data')
             ? $obj->{$_}
             : SOAP::Data->name($_ => $obj->{$_})
-        } keys $obj
+        } keys %$obj
       ))
     } @_;
 }
@@ -71,7 +71,7 @@ WWW::SFDC::Partner - Interface to the Salesforce.com Partner API
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
