@@ -45,7 +45,7 @@ sub _prepareSObjects {
           (blessed ($obj->{$_}) and blessed ($obj->{$_}) eq 'SOAP::Data')
             ? $obj->{$_}
             : SOAP::Data->name($_ => $obj->{$_})
-        } keys $obj
+        } keys %$obj
       ))->type($type)
     } @_;
 }
@@ -109,7 +109,7 @@ WWW::SFDC::Tooling - Interface to the Salesforce.com Tooling API
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
